/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.translation.internal.workflow;

import com.liferay.portal.configuration.metatype.bnd.util.ConfigurableUtil;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.security.permission.ResourceActionsUtil;
import com.liferay.portal.kernel.service.ServiceContext;
import com.liferay.portal.kernel.util.GetterUtil;
import com.liferay.portal.kernel.workflow.BaseWorkflowHandler;
import com.liferay.portal.kernel.workflow.WorkflowConstants;
import com.liferay.portal.kernel.workflow.WorkflowHandler;
import com.liferay.translation.internal.configuration.FFTranslationWorkflowConfiguration;
import com.liferay.translation.model.TranslationEntry;
import com.liferay.translation.service.TranslationEntryLocalService;

import java.io.Serializable;

import java.util.Locale;
import java.util.Map;

import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Modified;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Alicia Garcia
 */
@Component(
	configurationPid = "com.liferay.translation.internal.configuration.FFTranslationWorkflowConfiguration",
	property = "model.class.name=com.liferay.translation.model.TranslationEntry",
	service = WorkflowHandler.class
)
public class TranslationEntryWorkflowHandler
	extends BaseWorkflowHandler<TranslationEntry> {

	@Override
	public String getClassName() {
		return TranslationEntry.class.getName();
	}

	@Override
	public String getType(Locale locale) {
		return ResourceActionsUtil.getModelResource(locale, getClassName());
	}

	@Override
	public boolean isVisible() {
		return _ffTranslationWorkflowConfiguration.enabled();
	}

	@Override
	public TranslationEntry updateStatus(
			int status, Map<String, Serializable> workflowContext)
		throws PortalException {

		long userId = GetterUtil.getLong(
			(String)workflowContext.get(WorkflowConstants.CONTEXT_USER_ID));
		long classPK = GetterUtil.getLong(
			(String)workflowContext.get(
				WorkflowConstants.CONTEXT_ENTRY_CLASS_PK));

		ServiceContext serviceContext = (ServiceContext)workflowContext.get(
			"serviceContext");

		return _translationEntryLocalService.updateStatus(
			userId, classPK, status, serviceContext, workflowContext);
	}

	@Activate
	@Modified
	protected void activate(Map<String, Object> properties) {
		_ffTranslationWorkflowConfiguration =
			ConfigurableUtil.createConfigurable(
				FFTranslationWorkflowConfiguration.class, properties);
	}

	private FFTranslationWorkflowConfiguration
		_ffTranslationWorkflowConfiguration;

	@Reference
	private TranslationEntryLocalService _translationEntryLocalService;

}